@@ -224,7 +224,7 @@ cleanup (void)
 
   /* Free the used data */
   if (paths) {
-    g_list_deep_free (paths, NULL);
+    g_list_free_full (paths, g_free);
     paths = NULL;
   }
   /* Forcibly invalidate the iterator */
@@ -302,11 +302,7 @@ confirm_overwrite_existing_file (GFile *uri, int *overwrite_mode, goffset info_s
   char *display_name, *filename, *size;
 
   display_name = g_file_get_parse_name (uri);
-#if GLIB_CHECK_VERSION(2,30,0)
   size = g_format_size (info_size);
-#else
-  size = g_format_size_for_display(info_size);
-#endif
   dialog = gtk_message_dialog_new (GTK_WINDOW (main_window), GTK_DIALOG_MODAL,
                                    GTK_MESSAGE_QUESTION,
                                    GTK_BUTTONS_NONE,
